@@ -12,5 +12,5 @@ from designer.objects.line import line
 from designer.objects.rectangle import rectangle
 from designer.objects.shape import shape, lines
 from designer.objects.text import text
-from designer.objects.emoji import emoji
+from designer.objects.emoji import emoji, get_emoji_name, set_emoji_name
 from designer.objects.pen import pen
\ No newline at end of file
