@@ -129,7 +129,7 @@ class Emoji(DesignerObject):
         image. In order: flipping, scaling, and rotation.
         """
         # Transform the SVG
-        l, r = self._size * self._scale
+        l, r = Vec2D(self.DEFAULT_EMOJI_SIZE, self.DEFAULT_EMOJI_SIZE) * self._scale
         flip_x, flip_y = "-" if self._flip_x else "", "-" if self._flip_y else ""
         transforms = f"rotate({self._angle})\nscale({flip_x}{self._scale[0]}, {flip_y}{self._scale[1]})"
         image_data = (f'<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 {l} {r}">'
@@ -222,3 +222,12 @@ def emoji(name, x=None, y=None, anchor='center', **kwargs):
 if ALT_MODE:
     Emoji._load_image = Emoji._alt_load_image
     Emoji._redraw_internal_image = Emoji._alt_redraw_internal_image
+
+
+def get_emoji_name(an_emoji: Emoji) -> str:
+    return an_emoji.name
+
+
+def set_emoji_name(an_emoji: Emoji, new_name: str):
+    an_emoji.name = new_name
+
