@@ -3,19 +3,19 @@ from designer.objects.designer_object import DesignerObject
 
 def _detect_objects_recursively(data):
     """ Recursively detects any references to DesignerObjects,
-     and returns them as a flattened list. """
+     and returns them as a flattened set. """
     if isinstance(data, (list, set, tuple, frozenset)):
-        result = []
+        result = set()
         for item in data:
-            result.extend(_detect_objects_recursively(item))
+            result.update(_detect_objects_recursively(item))
         return result
     elif isinstance(data, dict):
-        result = []
+        result = set()
         for key, value in data.items():
-            result.extend(_detect_objects_recursively(key))
-            result.extend(_detect_objects_recursively(value))
+            result.update(_detect_objects_recursively(key))
+            result.update(_detect_objects_recursively(value))
         return result
     elif isinstance(data, DesignerObject):
-        return [data]
+        return {data}
     else:
-        return []
\ No newline at end of file
+        return set()
